# Generated by Django 5.1.3 on 2024-12-03 13:49

import django.db.models.expressions
import pictures.models
import utils.upload
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BaseFile',
            fields=[
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, help_text='The unique ID (UUID4) of this object.', primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='The date and time when this object was first created.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='The date and time when this object was last updated.')),
                ('title', models.CharField(help_text='The title of this work. Required. Defaults to the original uploaded filename.', max_length=255)),
                ('description', models.TextField(blank=True, help_text='The description of this work. Optional. Supports markdown.')),
                ('original_source', models.URLField(blank=True, help_text='The URL to the original CC source of this work. Leave blank to consider the BMA URL the original source.')),
                ('original_filename', models.CharField(help_text='The original (uploaded) filename. This value is read-only.', max_length=255)),
                ('file_size', models.BigIntegerField(help_text='The size of the file in bytes. This value is read-only.')),
                ('mimetype', models.CharField(help_text='The mimetype of the file as reported the uploading client. This value is read-only.', max_length=255)),
                ('license', models.CharField(choices=[('CC_ZERO_1_0', 'Creative Commons CC0 1.0 Universal'), ('CC_BY_4_0', 'Creative Commons Attribution 4.0 International'), ('CC_BY_SA_4_0', 'Creative Commons Attribution-ShareAlike 4.0 International')], help_text='The license for this file. The license can not be changed or revoked after the file is uploaded.', max_length=20)),
                ('attribution', models.CharField(help_text='The attribution text for this file. This is usually the real name or handle of the author(s) or licensor of the file.', max_length=255)),
                ('approved', models.BooleanField(default=False, help_text='Has this file been approved by a moderator?')),
                ('published', models.BooleanField(default=False, help_text='Has this file been published?')),
                ('deleted', models.BooleanField(default=False, help_text='Has this file been deleted?')),
            ],
            options={
                'verbose_name': 'file',
                'verbose_name_plural': 'files',
                'ordering': ('created_at',),
                'permissions': (('unapprove_basefile', 'Unapprove file'), ('approve_basefile', 'Approve file'), ('unpublish_basefile', 'Unpublish file'), ('publish_basefile', 'Publish file'), ('undelete_basefile', 'Undelete file'), ('softdelete_basefile', 'Soft delete file')),
            },
        ),
        migrations.CreateModel(
            name='FileGroupObjectPermission',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FileUserObjectPermission',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Thumbnail',
            fields=[
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('file_size', models.BigIntegerField(help_text='The size of the file in bytes. This value is read-only.')),
                ('mimetype', models.CharField(help_text='The mimetype of the file as reported the uploading client. This value is read-only.', max_length=255)),
                ('width', models.PositiveIntegerField(help_text='The width of this image (in pixels).')),
                ('height', models.PositiveIntegerField(help_text='The height of this image (in pixels).')),
                ('aspect_ratio', models.CharField(help_text="The intended (and advertised) aspect ratio of this image, expressed as a string like '16/9'. The actual image AR (width/height) can vary slightly from the value in this field because of rounding errors when resizing images.", max_length=20)),
                ('pixels', models.GeneratedField(db_persist=True, expression=django.db.models.expressions.CombinedExpression(models.F('width'), '*', models.F('height')), help_text='The total number of pixels in this image. Useful for ordering by image size.', output_field=models.PositiveBigIntegerField())),
                ('imagefile', pictures.models.PictureField(aspect_ratios=[None], breakpoints={'lg': 992, 'md': 768, 'sm': 576, 'xl': 1200, 'xs': 0, 'xxl': 1400}, container_width=4000, file_types=['WEBP'], grid_columns=12, height_field='height', help_text='The thumbnail file.', max_length=255, pixel_densities=[1, 2], upload_to=utils.upload.get_thumbnail_path, width_field='width')),
            ],
            options={
                'ordering': ('-width',),
            },
        ),
        migrations.CreateModel(
            name='ThumbnailSource',
            fields=[
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('file_size', models.BigIntegerField(help_text='The size of the file in bytes. This value is read-only.')),
                ('mimetype', models.CharField(help_text='The mimetype of the file as reported the uploading client. This value is read-only.', max_length=255)),
                ('width', models.PositiveIntegerField(help_text='The width of this image (in pixels).')),
                ('height', models.PositiveIntegerField(help_text='The height of this image (in pixels).')),
                ('aspect_ratio', models.CharField(help_text="The intended (and advertised) aspect ratio of this image, expressed as a string like '16/9'. The actual image AR (width/height) can vary slightly from the value in this field because of rounding errors when resizing images.", max_length=20)),
                ('pixels', models.GeneratedField(db_persist=True, expression=django.db.models.expressions.CombinedExpression(models.F('width'), '*', models.F('height')), help_text='The total number of pixels in this image. Useful for ordering by image size.', output_field=models.PositiveBigIntegerField())),
                ('source', pictures.models.PictureField(aspect_ratios=['1/1', '4/3', '16/9', '2/3'], breakpoints={'lg': 992, 'md': 768, 'sm': 576, 'xl': 1200, 'xs': 0, 'xxl': 1400}, container_width=200, file_types=['WEBP'], grid_columns=4, height_field='height', help_text='The source image from which all the thumbnails are created.', max_length=255, pixel_densities=[1, 2], upload_to=utils.upload.get_thumbnail_source_path, width_field='width')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
